<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
    xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

	<!--インベントリ情報をエクスポート-->

	<xsl:output method="text" media-type="text/plain" encoding="UTF-8" indent="no"/>
	<xsl:param name="header"/>
	<xsl:param name="appCount"/>

	<xsl:include href="Function.xslt" />

	<xsl:template match="/">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="Root">
		<xsl:call-template name="setting"/>
	</xsl:template>

	<xsl:template name="setting">
		<xsl:call-template name ="text">
			<xsl:with-param name="title" select="'AppleID'"/>
			<xsl:with-param name="this" select="/Root/AppleID"/>
		</xsl:call-template>

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'SSID'"/>
			<xsl:with-param name="this" select="Networks/Network/SSID"/>
		</xsl:call-template>

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'IPアドレス設定方法'"/>
			<xsl:with-param name="this">
				<xsl:call-template name ="NetworkConfigMethod">
					<xsl:with-param name="value" select="Networks/Network/ConfigMethod"/>
				</xsl:call-template>
			</xsl:with-param>
		</xsl:call-template>

		<!-- <xsl:if test="Networks/Network/ConfigMethod = 'Manual'"> -->
		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'IPアドレス'"/>
			<xsl:with-param name="this" select="Networks/Network/Addresses"/>
		</xsl:call-template>

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'サブネットマスク'"/>
			<xsl:with-param name="this" select="Networks/Network/SubnetMasks"/>
		</xsl:call-template>

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'ルーター'"/>
			<xsl:with-param name="this" select="Networks/Network/Router"/>
		</xsl:call-template>
		<!-- </xsl:if> -->

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'DNS'"/>
			<xsl:with-param name="this">
				<xsl:call-template name ="httpproxy">
					<xsl:with-param name="value" select="Networks/Network/DNS"/>
				</xsl:call-template>
			</xsl:with-param>
		</xsl:call-template>

		<!-- <xsl:if test="Networks/Network/DNS = 'Manual'"> -->
		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'DNSサーバ'"/>
			<xsl:with-param name="this" select="Networks/Network/ServerAddresses"/>
		</xsl:call-template>
		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'検索ドメイン'"/>
			<xsl:with-param name="this" select="Networks/Network/SearchDomains"/>
		</xsl:call-template>
		<!-- </xsl:if> -->

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'HTTPプロキシ'"/>
			<xsl:with-param name="this">
				<xsl:call-template name ="httpproxy">
					<xsl:with-param name="value" select="Networks/Network/ProxyMode"/>
				</xsl:call-template>
			</xsl:with-param>
		</xsl:call-template>



		<!-- <xsl:if test="Networks/Network/ProxyMode = 'Auto'"> -->
		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'URL'"/>
			<xsl:with-param name="this" select="Networks/Network/ProxyAutoConfigURLString"/>
		</xsl:call-template>
		<!-- </xsl:if> -->
		<!-- <xsl:if test="Networks/Network/ProxyMode = 'Manual'"> -->
		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'サーバ'"/>
			<xsl:with-param name="this" select="Networks/Network/ProxyHTTPProxy"/>
		</xsl:call-template>
		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'ポート'"/>
			<xsl:with-param name="this" select="Networks/Network/ProxyHTTPPort"/>
		</xsl:call-template>
		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'認証'"/>
			<xsl:with-param name="this">
				<xsl:choose>
					<xsl:when test="Networks/Network/HTTPProxyAuthenticated = '1'">
						<xsl:text>オン</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>オフ</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:call-template>
		<!-- <xsl:if test="Networks/Network/HTTPProxyAuthenticated = '1'"> -->
		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'ユーザ名'"/>
			<xsl:with-param name="this" select="Networks/Network/HTTPProxyUsername"/>
		</xsl:call-template>
		<!-- </xsl:if> -->
		<!-- </xsl:if> -->


		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'名前'"/>
			<xsl:with-param name="this" select="/Root/DeviceName"/>
		</xsl:call-template>

		<xsl:call-template name ="text">
			<xsl:with-param name="title" select="'ビデオ'"/>
			<xsl:with-param name="this" select="/Root/VideoCount"/>
		</xsl:call-template>
		<xsl:call-template name ="text">
			<xsl:with-param name="title" select="'写真'"/>
			<xsl:with-param name="this" select="/Root/PhotoCount"/>
		</xsl:call-template>

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'容量'"/>
			<xsl:with-param name="this">
				<xsl:value-of select="round(DiskCapacity div 1000)"/>
				<xsl:text>GB</xsl:text>
			</xsl:with-param>
		</xsl:call-template>

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'使用可能'"/>
			<xsl:with-param name="this">
				<xsl:value-of select="round(DataAvailable div 10) div 100"/>
				<xsl:text>GB</xsl:text>
			</xsl:with-param>
		</xsl:call-template>

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'バージョン'"/>
			<xsl:with-param name="this" select="ProductVersion"/>
		</xsl:call-template>

		<xsl:call-template name="text">
			<xsl:with-param name="title" select="'シリアル番号'"/>
			<xsl:with-param name="this" select="SerialNumber"/>
		</xsl:call-template>

		<xsl:if test="$header = '1' and $appCount &gt; 0">
			<xsl:call-template name="Repeat">
              <xsl:with-param name="only1st" select="'false'"/>
              <xsl:with-param name="other" select="''"/>
              <xsl:with-param name="text">
			  <xsl:text>App[{0}],リリースバージョン,ビルドバージョン</xsl:text>
			  </xsl:with-param>
              <xsl:with-param name="count" select="$appCount"/>
            </xsl:call-template>
		</xsl:if>
		
	</xsl:template>


	<xsl:template name="text">
		<xsl:param name="title" select="aaa"/>
		<xsl:param name="this" select=""/>
		<xsl:if test="$header = '1'">
			<xsl:value-of select="$title"/>
			<xsl:text>,</xsl:text>
		</xsl:if>
		<xsl:if test="$header != '1'">
			<xsl:text>"=""</xsl:text>
			<xsl:value-of select="$this"/>
			<xsl:text>""",</xsl:text>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="Repeat">
    <xsl:param name="only1st" select="'false'"/>
    <xsl:param name="other" />
    <xsl:param name="index" select="1"/>
    <xsl:param name="count"/>
    <xsl:param name="text"/>

    <xsl:if test="number($index) &lt;= $count">    
      <xsl:choose>
        <xsl:when test="($only1st='true' and $index=1) or (not($only1st) or $only1st='false')">
          <xsl:value-of select="cs:Replace($text,$index)"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$other"/>
        </xsl:otherwise>
      </xsl:choose>
	  <xsl:text>,</xsl:text>
	  <xsl:call-template name="Repeat">
        <xsl:with-param name="only1st" select="$only1st"/>
        <xsl:with-param name="other" select="$other"/>
        <xsl:with-param name="index" select="number($index) + 1"/>
        <xsl:with-param name="count" select="$count"/>
        <xsl:with-param name="text" select="$text"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>